<?php

namespace Drupal\open_lms_quiz\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Quiz Submission entities.
 *
 * @ingroup open_lms_quiz
 */
interface QuizSubmissionInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {

  // Add get/set methods for your configuration properties here.

  /**
   * Gets the Quiz Submission name.
   *
   * @return string
   *   Name of the Quiz Submission.
   */
  public function getName();

  /**
   * Sets the Quiz Submission name.
   *
   * @param string $name
   *   The Quiz Submission name.
   *
   * @return \Drupal\open_lms_quiz\Entity\QuizSubmissionInterface
   *   The called Quiz Submission entity.
   */
  public function setName($name);

  /**
   * Gets the Quiz Submission creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Quiz Submission.
   */
  public function getCreatedTime();

  /**
   * Sets the Quiz Submission creation timestamp.
   *
   * @param int $timestamp
   *   The Quiz Submission creation timestamp.
   *
   * @return \Drupal\open_lms_quiz\Entity\QuizSubmissionInterface
   *   The called Quiz Submission entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Quiz Submission published status indicator.
   *
   * Unpublished Quiz Submission are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Quiz Submission is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Quiz Submission.
   *
   * @param bool $published
   *   TRUE to set this Quiz Submission to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\open_lms_quiz\Entity\QuizSubmissionInterface
   *   The called Quiz Submission entity.
   */
  public function setPublished($published);

}
